"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SentryInterceptor = void 0;
const rxjs_1 = require("rxjs");
const common_1 = require("@nestjs/common");
const Sentry = __importStar(require("@sentry/node"));
const executionContextUtils_1 = require("../executionContextUtils");
const SentryKeys = __importStar(require("../sentryKeys"));
class SentryInterceptor {
    constructor(options) {
        this.options = options;
        this.loggerName = 'Sentry';
        this.logger = new common_1.Logger(this.loggerName);
    }
    captureExceptionHttpContext(context, error) {
        const { controller, method } = (0, executionContextUtils_1.getRouteInfo)(context);
        Sentry.withScope(() => {
            Sentry.setTag(SentryKeys.ROUTE_CONTROLLER, controller);
            Sentry.setTag(SentryKeys.ROUTE_METHOD, method);
            if (error instanceof common_1.HttpException) {
                Sentry.setTag(SentryKeys.IS_HTTP_EXCEPTION, true);
                Sentry.setTag(SentryKeys.RESPONSE_STATUS_CODE, error.getStatus());
                Sentry.setExtra(SentryKeys.RESPONSE, error.getResponse());
            }
            else {
                Sentry.setTag(SentryKeys.IS_HTTP_EXCEPTION, false);
            }
            this.logger.verbose('Capture exception is Http contex');
            Sentry.captureException(error);
        });
    }
    captureExceptionRqmContext(context, error) {
        const { controller, method } = (0, executionContextUtils_1.getRouteInfo)(context);
        Sentry.withScope(() => {
            Sentry.setTag(SentryKeys.ROUTE_CONTROLLER, controller);
            Sentry.setTag(SentryKeys.ROUTE_METHOD, method);
            this.logger.verbose('Capture exception is Rqm contex');
            Sentry.captureException(error);
        });
    }
    captureException(context, exception) {
        var _a, _b;
        if (!process.env.SENTRY_DSN) {
            this.logger.verbose('Sentry DNS not set, skipping capture exception');
            return;
        }
        const contextType = context.getType();
        if (contextType === 'rmq' && ((_a = this.options) === null || _a === void 0 ? void 0 : _a.applyForRqmContext))
            this.captureExceptionRqmContext(context, exception);
        if (contextType === 'http' && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.applyForHttpContext))
            this.captureExceptionHttpContext(context, exception);
    }
    intercept(context, next) {
        return next.handle().pipe((0, rxjs_1.catchError)((error) => {
            this.captureException(context, error);
            throw error;
        }));
    }
}
exports.SentryInterceptor = SentryInterceptor;
//# sourceMappingURL=sentry.interceptor.js.map